==> cpg1.4.x_plugin_jupload_v3.5.1.zip: jupload/configuration.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://etienne.sf.free.fr/wiki/doku.php?id=jupload_coppermine_download_gb
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}

$name='JUpload plugin Plugin';
$description='Java applet that allows picture management (preview, resizing, rotation). The juploap.php script also allows basic album management (creation, update of name and description).';
$author='Etienne Gauthier';

/*
 * $install_info is displayed with the title of a plugin that _is_ installed and
 * can be used to present extra information. Here is displayed a link toward a
 * configuration page.
 */
$install_info=<<<EOT
    <table border="0" cellspacing="10" cellpadding="0"> 
    <tr>
        <td class="admin_menu">
        	<a 
        		href="index.php?file=jupload/jupload&action=config" 
        		title="Plugin Configuration">
        	JUpload configuration
        	</a>
        </td>
        <td class="admin_menu">
        	<a target="_blank" href="http://forum.coppermine-gallery.net/index.php/board,100.0.html" title="JUpload Support">
        		Support
        	</a>
        </td>
        <td class="admin_menu">
        	<a target="_blank" href="http://etienne.sf.free.fr/wiki/doku.php?id=jupload_coppermine_gb" title="JUpload home page">
        		JUpload info
        	</a>
        </td>
    </tr>
    </table>
EOT;


//Let's create a 'default' version number, for my internal tests
$version = '[not packaged]'; 
//This internal version number should be replaced by the next line, added during packaging
//Ok, this could be better. But it works, that's a point !    ;-)

$version='3.5.1';

==> cpg1.5.x_plugin_jupload_v4.0.0_rc3.zip: jupload/configuration.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://forum.coppermine-gallery.net/index.php/board,100.0.html
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}

$name='JUpload plugin Plugin';
$description='Java applet that allows picture management (preview, resizing, rotation). The juploap.php script also allows basic album management (creation, update of name and description).';
$author='etienne_sf';

/*
 * $install_info is displayed with the title of a plugin that _is_ installed and
 * can be used to present extra information. Here is displayed a link toward a
 * configuration page.
 */
$install_info=<<<EOT
    <table border="0" cellspacing="10" cellpadding="0"> 
    <tr>
        <td class="admin_menu">
        	<a 
        		href="index.php?file=jupload/jupload&action=config" 
        		title="Plugin Configuration">
        	JUpload configuration
        	</a>
        </td>
        <td class="admin_menu">
        	<a target="_blank" href="http://forum.coppermine-gallery.net/index.php/board,100.0.html" title="JUpload Support">
        		Support
        	</a>
        </td>
        <td class="admin_menu">
        	<a target="_blank" href="http://etienne.sf.free.fr/wiki/doku.php?id=jupload_coppermine_gb" title="JUpload home page">
        		JUpload info
        	</a>
        </td>
    </tr>
    </table>
EOT;

//For coppermine 1.5:
$extra_info = $install_info;


//Let's create a 'default' version number, for my internal tests
$version = '[not packaged]'; 
//This internal version number should be replaced by the next line, added during packaging
//Ok, this could be better. But it works, that's a point !    ;-)

$version='4.0.0rc3';
